from ._core import (
    charset_encoding,
    content,
    cookies,
    elapsed,
    encoding,
    has_redirect_location,
    headers,
    history,
    http_version,
    is_client_error,
    is_closed,
    is_error,
    is_informational,
    is_redirect,
    is_server_error,
    is_stream_consumed,
    is_success,
    json,
    links,
    next_request,
    num_bytes_downloaded,
    reason_phrase,
    request,
    request_content,
    request_headers,
    request_method,
    request_params,
    request_stream,
    request_url,
    response,
    status_code,
    stream,
    text,
    url,
)
from ._headers import header, location, server



from dataclasses import dataclass
from typing import Callable, Optional, Sequence

from neoclient.enums import HTTPHeader

from ..models import Headers

__all__: Sequence[str] = ("header", "location", "server")


@dataclass
class HeaderDependency:
    key: str

    def __call__(self, headers: Headers, /) -> Optional[str]:
        return headers.get(self.key)


def header(key: str, /) -> Callable[..., Optional[str]]:
    return HeaderDependency(key)


location: Callable[..., Optional[str]] = header(HTTPHeader.LOCATION)
server: Callable[..., Optional[str]] = header(HTTPHeader.SERVER)
